@@ -44,7 +44,7 @@ AutoProperties::AutoProperties(void)
     _instance = this;
 
     // fill parsing maps
-    _apply_on_map[""] = APPLY_ON_NONE;
+    _apply_on_map[""] = APPLY_ON_ALWAYS;
     _apply_on_map["START"] = APPLY_ON_START;
     _apply_on_map["NEW"] = APPLY_ON_NEW;
     _apply_on_map["RELOAD"] = APPLY_ON_RELOAD;
@@ -212,7 +212,7 @@ AutoProperties::loadRequire(CfgParser &a_cfg, std::string &file)
 void
 AutoProperties::unload(void)
 {
-    list<Property*>::iterator it;
+    vector<Property*>::iterator it;
 
     // remove auto properties
     for (it = _prop_list.begin(); it != _prop_list.end(); ++it) {
@@ -249,25 +249,26 @@ AutoProperties::unload(void)
 //! @brief Finds a property from the prop_list
 Property*
 AutoProperties::findProperty(const ClassHint* class_hint,
-                             std::list<Property*>* prop_list, int ws, uint type)
+                             std::vector<Property*>* prop_list, int ws, ApplyOn type)
 {
     // Allready remove apply on start
     if (! _apply_on_start && (type == APPLY_ON_START))
         return 0;
 
-    list<Property*>::iterator it(prop_list->begin());
+    vector<Property*>::const_iterator it(prop_list->begin());
+    vector<Property*>::const_iterator end(prop_list->end());
     list<uint>::iterator w_it;
 
     // start searching for a suitable property
-    for (; it != prop_list->end(); ++it) {
+    for (; it != end; ++it) {
         // see if the type matches, if we have one
-        if ((type != 0) && ! (*it)->isApplyOn(type))
+        if ((type != APPLY_ON_ALWAYS) && ! (*it)->isApplyOn(type))
             continue;
 
         if (matchAutoClass(*class_hint, *it)) {
 
             // make sure it applies on the correct workspace
-            if ((*it)->getWsList().size()) {
+            if (! (*it)->getWsList().empty()) {
                 w_it = find((*it)->getWsList().begin(), (*it)->getWsList().end(),
                             unsigned(ws));
                 if (w_it != (*it)->getWsList().end()) {
@@ -836,7 +837,7 @@ AutoProperties::parseAutoPropertyValue(CfgParser::Entry *section, AutoProperty *
 
 //! @brief Searches the _prop_list for a property
 AutoProperty*
-AutoProperties::findAutoProperty(const ClassHint* class_hint, int ws, uint type)
+AutoProperties::findAutoProperty(const ClassHint* class_hint, int ws, ApplyOn type)
 {
     return static_cast<AutoProperty*>(findProperty(class_hint, &_prop_list, ws, type));
 }
@@ -845,20 +846,20 @@ AutoProperties::findAutoProperty(const ClassHint* class_hint, int ws, uint type)
 TitleProperty*
 AutoProperties::findTitleProperty(const ClassHint* class_hint)
 {
-    return static_cast<TitleProperty*>(findProperty(class_hint, &_title_prop_list, -1, 0));
+    return static_cast<TitleProperty*>(findProperty(class_hint, &_title_prop_list, -1, APPLY_ON_ALWAYS));
 }
 
 //! @brief
 DecorProperty*
 AutoProperties::findDecorProperty(const ClassHint* class_hint)
 {
-    return static_cast<DecorProperty*>(findProperty(class_hint, &_decor_prop_list, -1, 0));
+    return static_cast<DecorProperty*>(findProperty(class_hint, &_decor_prop_list, -1, APPLY_ON_ALWAYS));
 }
 
 DockAppProperty*
 AutoProperties::findDockAppProperty(const ClassHint *class_hint)
 {
-    return static_cast<DockAppProperty*>(findProperty(class_hint, &_dock_app_prop_list, -1, 0));
+    return static_cast<DockAppProperty*>(findProperty(class_hint, &_dock_app_prop_list, -1, APPLY_ON_ALWAYS));
 }
 
 //! @brief Get AutoProperty for window of type type
@@ -880,7 +881,7 @@ AutoProperties::findWindowTypeProperty(AtomName atom)
 void
 AutoProperties::removeApplyOnStart(void)
 {
-    list<Property*>::iterator it(_prop_list.begin());
+    vector<Property*>::iterator it(_prop_list.begin());
     for (; it != _prop_list.end(); ++it) {
         if ((*it)->isApplyOn(APPLY_ON_START)) {
             (*it)->applyRemove(APPLY_ON_START);
