@@ -46,7 +46,7 @@ CfgParser::Entry::Entry(const std::string &source_name, int line,
 CfgParser::Entry::Entry(const CfgParser::Entry &entry)
     : _section(0),
       _name(entry._name), _value(entry._value),
-      _line(entry._line), _source_name(_source_name)
+      _line(entry._line), _source_name(entry._source_name)
 {
     list<CfgParser::Entry*>::const_iterator it(entry._entries.begin());
     for (; it != entry._entries.end(); ++it) {
@@ -120,7 +120,7 @@ CfgParser::Entry::set_section(CfgParser::Entry *section, bool overwrite)
 {
     if (_section) {
         if (overwrite) {
-            _section->copy_tree_into(section);
+            _section->copy_tree_into(section, overwrite);
             delete section;
         } else {
             delete _section;
@@ -191,6 +191,30 @@ CfgParser::Entry::parse_key_values(std::list<CfgParserKey*>::iterator begin,
     }
 }
 
+/**
+   Print tree to stderr.
+*/
+void
+CfgParser::Entry::print(uint level)
+{
+    for (uint i = 0; i < level; ++i) {
+        cerr << " ";
+    }
+    cerr << " * " << get_name() << "=" << get_value() << endl;
+
+    CfgParser::iterator it(begin());
+    for (; it != end(); ++it) {
+        if ((*it)->get_section()) {
+            (*it)->get_section()->print(level + 1);
+        } else {
+            for (uint i = 0; i < level; ++i) {
+                cerr << " ";
+            }
+            cerr << "   - " << get_name() << "=" << get_value() << endl;
+        }
+    }
+}
+
 /**
  * Copy tree into current entry, overwrite entries if overwrite is
  * true.
