@@ -162,7 +162,7 @@ Frame::Frame(Client *client, AutoProperty *ap)
     // I add these to the list before I insert the client into the frame to
     // be able to skip an extra updateClientList
     _frame_list.push_back(this);
-    WindowManager::instance()->addToFrameList(this);
+    WindowManager::instance()->addToMRUBack(this);
     Workspaces::insert(this);
 
     activateChild(client);
@@ -481,8 +481,11 @@ Frame::addChildOrdered (Client *child)
 
 //! @brief Removes child from the frame.
 void
-Frame::removeChild (PWinObj *child, bool do_delete)
+Frame::removeChild(PWinObj *child, bool do_delete)
 {
+    if (static_cast<Client *>(child)->demandsAttention()) {
+        --_attention;
+    }
     PDecor::removeChild(child, do_delete);
 }
 
@@ -988,7 +991,10 @@ bool
 Frame::fixGeometry(void)
 {
     Geometry head, before;
-    X11::getHeadInfoWithEdge(getNearestHead(), head);
+    if (_fullscreen)
+        X11::getHeadInfo(getNearestHead(), head);
+    else
+        X11::getHeadInfoWithEdge(getNearestHead(), head);
 
     before = _gm;
 
@@ -1616,7 +1622,7 @@ Frame::setStateSticky(StateAction sa)
 void
 Frame::setStateAlwaysOnTop(StateAction sa)
 {
-    if (! ActionUtil::needToggle(sa, getLayer() == LAYER_ONTOP)) {
+    if (! ActionUtil::needToggle(sa, getLayer() >= LAYER_ONTOP)) {
         return;
     }
 
@@ -1858,7 +1864,7 @@ Frame::close(void)
 //! @brief Reads autoprops for the active client.
 //! @param type Defaults to APPLY_ON_RELOAD
 void
-Frame::readAutoprops(uint type)
+Frame::readAutoprops(ApplyOn type)
 {
     if ((type != APPLY_ON_RELOAD) && (type != APPLY_ON_WORKSPACE))
         return;
