@@ -1,6 +1,6 @@
 //
 // Util.cc for pekwm
-// Copyright © 2002-2008 Claes Nästén <me@pekdon.net>
+// Copyright © 2002-2009 Claes Nästén <me@pekdon.net>
 //
 // misc.cc for aewm++
 // Copyright (C) 2000 Frank Hale <frankhale@yahoo.com>
@@ -14,23 +14,23 @@
 #include "config.h"
 #endif // HAVE_CONFIG_H
 
-#include <algorithm>
 #include <cerrno>
 #include <iostream>
 #include <sstream>
 #include <fstream>
 #include <list>
+#include <cstdio>
+#include <cstring>
+#include <cwchar>
 
+extern "C" {
 #include <iconv.h>
 #include <unistd.h>
 #include <sys/stat.h>
 #include <sys/types.h>
-
-#ifndef HAVE_SETENV
-#include <cstdio>
-#include <cstring>
+#include <pwd.h>
 #include <errno.h>
-#endif // HAVE_SETENV
+}
 
 #include "Util.hh"
 
@@ -45,10 +45,19 @@ using std::list;
 using std::ifstream;
 using std::ofstream;
 using std::find;
-
+using std::map;
+using std::getenv;
+using std::wcstombs;
+using std::wmemset;
+using std::mbstowcs;
+using std::exit;
 
 namespace Util {
 
+#ifndef HOST_NAME_MAX
+#define HOST_NAME_MAX 255
+#endif // HOST_NAME_MAX
+
 static iconv_t do_iconv_open(const char **from_names, const char **to_names);
 static size_t do_iconv (iconv_t ic, const char **inp, size_t *in_bytes,
                         char **outp, size_t *out_bytes);
@@ -96,6 +105,26 @@ forkExec(std::string command)
     }
 }
 
+/**
+ * Wrapper for gethostname returning a string instead of populating
+ * char buffer.
+ */
+std::string
+getHostname(void)
+{
+    string hostname;
+
+    // Set WM_CLIENT_MACHINE
+    char hostname_buf[HOST_NAME_MAX + 1];
+    if (! gethostname(hostname_buf, HOST_NAME_MAX)) {
+      // Make sure it is null terminated
+      hostname_buf[HOST_NAME_MAX] = '\0';
+      hostname = hostname_buf;
+    }
+
+    return hostname;
+}
+
 //! @brief Determines if the file exists
 bool
 isFile(const std::string &file)
@@ -144,21 +173,32 @@ isExecutable(const std::string &file)
     return false;
 }
 
+/**
+ * Get file mtime.
+ */
+time_t
+getMtime(const std::string &file)
+{
+    struct stat stat_buf;
+
+    if (! stat(file.c_str(), &stat_buf)) {
+        return stat_buf.st_mtime;
+    } else {
+        return 0;
+    }
+}
+
 /**
  * Check if file has different mtime than provided mtime.
  */
 bool
 isFileChanged(const std::string &file, time_t &mtime)
 {
-    struct stat stat_buf;
-
-    if (! stat(file.c_str(), &stat_buf)) {
-        if (stat_buf.st_mtime != mtime) {
-            mtime = stat_buf.st_mtime;
-            return true;
-        }
+    time_t cur_mtime = getMtime(file);
+    if (cur_mtime != mtime) {
+        mtime = cur_mtime;
+        return true;
     }
-
     return false;
 }
 
@@ -167,22 +207,22 @@ isFileChanged(const std::string &file, time_t &mtime)
  * from new_file, path or mtime.
  */
 bool
-requireReload(std::string &old_file, const std::string &new_file,  time_t &mtime)
+requireReload(std::map <std::string, time_t> &state, const std::string &file)
 {
-    bool reload = false;
-
-    // Reload if file is newer than mtime, if it's another file reload
-    // either way. isFileChanged is used to update mtime.
-    reload = isFileChanged(new_file, mtime);
-    if (old_file.compare(new_file)) {
-        reload = true;
+    // Check for the file, signal reload if not previously loaded.
+    map<string, time_t>::iterator it(state.find(file));
+    if (it == state.end()) {
+        return true;
     }
 
-    if (reload) {
-        old_file = new_file;
+    // Check state of all files, if one is updated reload.
+    for (it = state.begin(); it != state.end(); ++it) {
+        if (isFileChanged(it->first, it->second)) {
+            return true;
+        }
     }
 
-    return reload;
+    return false;
 }
 
 /**
@@ -214,6 +254,26 @@ copyTextFile(const std::string &from, const std::string &to)
     return true;
 }
 
+/**
+ * Get name of the current user.
+ */
+string
+getUserName(void)
+{
+    // Try to lookup current user with 
+    struct passwd *entry = getpwuid(geteuid());
+
+    if (entry && entry->pw_name) {
+        return entry->pw_name;
+    } else {
+        if (getenv("USER")) {
+            return getenv("USER");
+        } else {
+            return "UNKNOWN";
+        }
+    }
+}
+
 
 //! @brief Returns .extension of file
 std::string
@@ -261,10 +321,10 @@ expandFileName(std::string &file)
 //! @param vals Vector to put split values into
 //! @param sep Separators to use when splitting string
 //! @param max Maximum number of elements to put into vals (optional)
+//! @param include_empty Include empty elements, defaults to false.
 //! @return Number of tokens inserted into vals
 uint
-splitString(const std::string str, std::vector<std::string> &toks,
-            const char *sep, uint max)
+splitString(const std::string str, std::vector<std::string> &toks, const char *sep, uint max, bool include_empty)
 {
     if (str.size() < 1) {
         return 0;
@@ -286,28 +346,19 @@ splitString(const std::string str, std::vector<std::string> &toks,
             break;
         }
 
-        s = str.find_first_not_of(sep, e);
+        if (include_empty) {
+            s = str.find_first_of(sep, e + 1);
+            if (s != (e + 1)) {
+                s = str.find_first_not_of(sep, e);
+            }
+        } else {
+            s = str.find_first_not_of(sep, e);
+        }
     }
 
     return (toks.size() - n);
 }
 
-//! @brief Converts string to uppercase
-//! @param str Reference to string to convert
-void
-to_upper(std::string &str)
-{
-    transform(str.begin(), str.end(), str.begin(), (int(*)(int)) std::toupper);
-}
-
-//! @brief Converts string to lowercase
-//! @param str Reference to string to convert
-void
-to_lower(std::string &str)
-{
-    transform(str.begin(), str.end(), str.begin(), (int(*)(int)) std::tolower);
-}
-
 //! @brief Converts wide-character string to multibyte version
 //! @param str String to convert.
 //! @return Returns multibyte version of string.
@@ -364,9 +415,13 @@ do_iconv_open(const char **from_names, const char **to_names)
     for (unsigned int i = 0; from_names[i]; ++i) {
         for (unsigned int j = 0; to_names[j]; ++j) {
             ic = iconv_open (to_names[j], from_names[i]);
-                if (ic != reinterpret_cast<iconv_t>(-1)) {
-                    return ic;
-                }
+            if (ic != reinterpret_cast<iconv_t>(-1)) {
+#ifdef HAVE_ICONVCTL
+                int int_value_one = 1;
+                iconvctl(ic, ICONV_SET_DISCARD_ILSEQ, &int_value_one);
+#endif // HAVE_ICONVCTL
+                return ic;
+            }
         }
     }
 
