@@ -14,10 +14,10 @@
 
 #include "Config.hh"
 #include "PixmapHandler.hh"
-#include "PScreen.hh"
 #include "ScreenResources.hh"
 #include "Workspaces.hh"
 #include "WorkspaceIndicator.hh"
+#include "x11.hh"
 
 using std::cerr;
 using std::endl;
@@ -38,7 +38,7 @@ WorkspaceIndicator::Display::Display(PWinObj *parent, Theme *theme)
     attr.override_redirect = false;
     attr.event_mask = ButtonPressMask|ButtonReleaseMask|ButtonMotionMask|
                     FocusChangeMask|KeyPressMask|KeyReleaseMask;
-    _window = XCreateWindow(_dpy, _parent->getWindow(), 0, 0, 1, 1, 0,
+    _window = XCreateWindow(X11::getDpy(), _parent->getWindow(), 0, 0, 1, 1, 0,
                             CopyFromParent, InputOutput, CopyFromParent,
                             CWOverrideRedirect|CWEventMask, &attr);
 }
@@ -48,7 +48,7 @@ WorkspaceIndicator::Display::Display(PWinObj *parent, Theme *theme)
  */
 WorkspaceIndicator::Display::~Display(void)
 {
-    XDestroyWindow(_dpy, _window);
+    XDestroyWindow(X11::getDpy(), _window);
     ScreenResources::instance()->getPixmapHandler()->returnPixmap(_pixmap);
 }
 
@@ -59,13 +59,13 @@ bool
 WorkspaceIndicator::Display::getSizeRequest(Geometry &gm)
 {
     Geometry head;
-    uint head_nr = PScreen::instance()->getNearestHead(_parent->getX(), _parent->getY());
-    PScreen::instance()->getHeadInfo(head_nr, head);
+    uint head_nr = X11::getNearestHead(_parent->getX(), _parent->getY());
+    X11::getHeadInfo(head_nr, head);
 
     uint head_size = std::min(head.width, head.height) / Config::instance()->getWorkspaceIndicatorScale();
     gm.x = gm.y = 0;
-    gm.width = head_size * Workspaces::instance()->getPerRow() + getPaddingHorizontal();
-    gm.height = head_size * Workspaces::instance()->getRows() + getPaddingVertical();
+    gm.width = head_size * Workspaces::getPerRow() + getPaddingHorizontal();
+    gm.height = head_size * Workspaces::getRows() + getPaddingVertical();
 
     return true;
 }
@@ -81,7 +81,7 @@ WorkspaceIndicator::Display::render(void)
     // Make sure pixmap has correct size
     ScreenResources::instance()->getPixmapHandler()->returnPixmap(_pixmap);
     _pixmap = ScreenResources::instance()->getPixmapHandler()->getPixmap(_gm.width, _gm.height,
-                                                                        PScreen::instance()->getDepth());
+                                                                        X11::getDepth());
 
     // Render background
     data.texture_background->render(_pixmap, 0, 0, _gm.width, _gm.height);
@@ -94,7 +94,7 @@ WorkspaceIndicator::Display::render(void)
 
     data.font->setColor(data.font_color);
     data.font->draw(_pixmap, data.edge_padding, _gm.height - data.edge_padding - data.font->getHeight(),
-                     Workspaces::instance()->getActiveWorkspace()->getName(),
+                     Workspaces::getActiveWorkspace()->getName(),
                      0 /* max_chars */, _gm.width - data.edge_padding * 2 /* max_width */);
 
     // Refresh
@@ -115,8 +115,8 @@ WorkspaceIndicator::Display::renderWorkspaces(int x, int y, uint width, uint hei
 {
     Theme::WorkspaceIndicatorData &data(_theme->getWorkspaceIndicatorData());
 
-    uint per_row = Workspaces::instance()->getPerRow();
-    uint rows = Workspaces::instance()->getRows();
+    uint per_row = Workspaces::getPerRow();
+    uint rows = Workspaces::getRows();
 
     uint ws_width = width / per_row;
     uint ws_height = height / rows;
@@ -125,18 +125,18 @@ WorkspaceIndicator::Display::renderWorkspaces(int x, int y, uint width, uint hei
     uint x_pos = x;
     uint y_pos = y;
 
-    vector<Workspaces::Workspace*>::iterator it(Workspaces::instance()->ws_begin());
+    vector<Workspaces::Workspace*>::iterator it(Workspaces::ws_begin());
 
-    for (uint row = 0; it != Workspaces::instance()->ws_end(); ++it) {
+    for (uint row = 0; it != Workspaces::ws_end(); ++it) {
         // Check for next row
-        if (Workspaces::instance()->getRow((*it)->getNumber()) > row) {
-            row = Workspaces::instance()->getRow((*it)->getNumber());
+        if (Workspaces::getRow((*it)->getNumber()) > row) {
+            row = Workspaces::getRow((*it)->getNumber());
 
             x_pos = x;
             y_pos += ws_height + data.workspace_padding;
         }
 
-        if ((*it)->getNumber() == Workspaces::instance()->getActive()) {
+        if ((*it)->getNumber() == Workspaces::getActive()) {
             data.texture_workspace_act->render(_pixmap, x_pos, y_pos, ws_width, ws_height);
         } else {
             data.texture_workspace->render(_pixmap, x_pos, y_pos, ws_width, ws_height);
@@ -154,7 +154,7 @@ WorkspaceIndicator::Display::getPaddingHorizontal(void)
 {
     Theme::WorkspaceIndicatorData &data(_theme->getWorkspaceIndicatorData());
 
-    return (data.edge_padding * 2 + data.workspace_padding * (Workspaces::instance()->getPerRow() - 1));
+    return (data.edge_padding * 2 + data.workspace_padding * (Workspaces::getPerRow() - 1));
 }
 
 /**
@@ -166,7 +166,7 @@ WorkspaceIndicator::Display::getPaddingVertical(void)
     Theme::WorkspaceIndicatorData &data(_theme->getWorkspaceIndicatorData());
 
     return (data.edge_padding * 3 + data.font->getHeight()
-            + data.workspace_padding * (Workspaces::instance()->getRows() - 1));
+            + data.workspace_padding * (Workspaces::getRows() - 1));
 }
 
 /**
@@ -198,13 +198,11 @@ WorkspaceIndicator::WorkspaceIndicator(Theme *theme, Timer<ActionPerformed> &tim
     loadTheme();
 
     // Register ourselves
-    Workspaces::instance()->insert(this);
+    Workspaces::insert(this);
     woListAdd(this);
     _wo_map[_window] = this;
 
-#ifdef OPACITY
     setOpacity(Config::instance()->getWorkspaceIndicatorOpacity());
-#endif // OPACITY
 }
 
 /**
@@ -215,7 +213,7 @@ WorkspaceIndicator::~WorkspaceIndicator(void)
     removeChild(&_display_wo, false);
 
     // Un-register ourselves
-    Workspaces::instance()->remove(this);
+    Workspaces::remove(this);
     _wo_map.erase(_window);
     woListRemove(this);
 }
@@ -228,7 +226,7 @@ WorkspaceIndicator::render(void)
 {
     // Center on head
     Geometry head, request;
-    PScreen::instance()->getHeadInfo(PScreen::instance()->getCurrHead(), head);
+    X11::getHeadInfo(X11::getCurrHead(), head);
 
     _display_wo.getSizeRequest(request);
     resizeChild(request.width, request.height);
