@@ -31,7 +31,9 @@ extern "C" {
 #endif // HAVE_XRANDR
 #include <X11/keysym.h> // For XK_ entries
 #include <sys/select.h>
-
+#ifdef HAVE_X11_XKBLIB_H
+#include <X11/XKBlib.h>
+#endif
 #ifdef DEBUG
 bool xerrors_ignore = false;
 #endif // DEBUG
@@ -156,6 +158,15 @@ X11::init(Display *dpy, bool honour_randr)
     }
 #endif // HAVE_XRANDR
 
+#ifdef HAVE_X11_XKBLIB_H
+    {
+        int major = XkbMajorVersion;
+        int minor = XkbMinorVersion;
+        int ext_opcode, ext_ev, ext_err;
+        _has_extension_xkb = XkbQueryExtension(_dpy, &ext_opcode, &ext_ev, &ext_err, &major, &minor);
+    }
+#endif // HAVE_X11_XKBLIB_H
+
     // Now screen geometry has been read and extensions have been
     // looked for, read head information.
     initHeads();
@@ -180,6 +191,12 @@ X11::destruct(void) {
     if (_modifier_map) {
         XFreeModifiermap(_modifier_map);
     }
+
+    // Under certain circumstances trying to restart pekwm can cause it to
+    // use 100% of the CPU without making any progress with the restart.
+    // This XSync() seems to be work around the issue (c.f. #300).
+    XSync(_dpy, true);
+
     XCloseDisplay(_dpy);
     _dpy = 0;
 }
@@ -714,6 +731,20 @@ X11::getKeycodeFromMask(uint mask)
     return 0;
 }
 
+/**
+ * Wrapper for XKeycodeToKeysym and XkbKeycodeToKeysym depending on which one is available.
+ */
+KeySym
+X11::getKeysymFromKeycode(KeyCode keycode)
+{
+#ifdef HAVE_X11_XKBLIB_H
+    if (_has_extension_xkb)
+        return XkbKeycodeToKeysym(_dpy, keycode, 0, 0);
+    else
+#endif
+        return XKeycodeToKeysym(_dpy, keycode, 0);
+}
+
 Display *X11::_dpy;
 bool X11::_honour_randr = false;
 int X11::_fd = -1;
@@ -726,6 +757,7 @@ Colormap X11::_colormap = None;
 XModifierKeymap *X11::_modifier_map;
 bool X11::_has_extension_shape = false;
 int X11::_event_shape = -1;
+bool X11::_has_extension_xkb = false;
 bool X11::_has_extension_xinerama = false;
 bool X11::_has_extension_xrandr = false;
 int X11::_event_xrandr = -1;
